# type: ignore
import sys
try:
    from assistant import set_excepthook
    from clipy import clipy
except ModuleNotFoundError:
    from coding_assistant.assistant import set_excepthook
    from coding_assistant.clipy import clipy


def cli():
    if len(sys.argv) < 2:
        # in the future allow for --character=
        print(f"Usage: {sys.argv[0]} <program.py> [<args> [...]]")
        exit(1)
    # futureproofing
    character = clipy

    set_excepthook(character)
    with open(sys.argv[1], "r") as f:
        # remove argv[0] from sys.argv
        sys.argv.pop(0)
        exec(f.read(), {
            'sys.excepthook': sys.excepthook,
        })



import setuptools
# source: https://shobhitgupta.medium.com/how-to-publish-your-own-pip-package-560bde836b17  # noqa
# this file was shamelessly stolen and then modified to fit
# this projet's needs

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="coding-assistant",
    version="0.1.0",
    author="Louis Sven Goulet",
    author_email="louis.sven@gmail.com",
    description=(
        "Recreate the joys of Office Assistant from "
        "the comfort of the Python interpreter"),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lorlouis/coding-assistant",
    packages=setuptools.find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={'console_scripts': [
        'coding-assistant = coding_assistant.cli:cli',
        'clipy = coding_assistant.cli:cli',
        ],
    },
    python_requires='>=3.9',
)



# type: ignore
import sys

_old_hook = sys.excepthook
_character = ""


def assistant_print(type_, value, tb):
    _old_hook(type_, value, tb)
    width = len(f"{type_.__qualname__}{f': {value}' if value else ''}")-2
    print(f"\\{'_'*width}/" + character)


def set_excepthook(assistant: str) -> None:
    global character
    character = assistant
    sys.excepthook = assistant_print
